@@ -3,27 +3,50 @@ import pickle
 import uuid
 
 import dagstermill
-from dagster_pandas import DataFrame
 
 from dagster import (
     DependencyDefinition,
-    Dict,
     Field,
+    FileHandle,
     InputDefinition,
     Int,
+    List,
     ModeDefinition,
     OutputDefinition,
     PipelineDefinition,
-    RepositoryDefinition,
     ResourceDefinition,
     SolidDefinition,
     SolidInvocation,
     String,
     check,
     lambda_solid,
+    pipeline,
+    repository,
     resource,
     solid,
 )
+from dagster.utils import PICKLE_PROTOCOL
+
+try:
+    from dagster_pandas import DataFrame
+
+    DAGSTER_PANDAS_PRESENT = True
+except ImportError:
+    DAGSTER_PANDAS_PRESENT = False
+
+try:
+    import sklearn as _
+
+    SKLEARN_PRESENT = True
+except ImportError:
+    SKLEARN_PRESENT = False
+
+try:
+    import matplotlib as _
+
+    MATPLOTLIB_PRESENT = True
+except ImportError:
+    MATPLOTLIB_PRESENT = False
 
 
 def nb_test_path(name):
@@ -44,9 +67,7 @@ def define_hello_world_config_solid():
     return dagstermill.define_dagstermill_solid(
         'hello_world_config',
         nb_test_path('hello_world_config'),
-        config_field=Field(
-            Dict({'greeting': Field(String, is_optional=True, default_value='hello')})
-        ),
+        config_schema={'greeting': Field(String, is_required=False, default_value='hello')},
     )
 
 
@@ -56,6 +77,28 @@ def define_hello_world_config_pipeline():
     )
 
 
+def define_hello_world_with_output_notebook_solid():
+    return dagstermill.define_dagstermill_solid(
+        'hello_world_with_output_notebook', nb_test_path('hello_world'), output_notebook='notebook',
+    )
+
+
+def define_hello_world_with_output_notebook_pipeline():
+    @solid(input_defs=[InputDefinition('notebook', dagster_type=FileHandle)])
+    def load_notebook_solid(_, notebook):
+        return os.path.exists(notebook.path_desc)
+
+    return PipelineDefinition(
+        name='hello_world_with_output_notebook_pipeline',
+        solid_defs=[define_hello_world_with_output_notebook_solid(), load_notebook_solid],
+        dependencies={
+            'load_notebook_solid': {
+                'notebook': DependencyDefinition('hello_world_with_output_notebook', 'notebook')
+            }
+        },
+    )
+
+
 def define_hello_world_with_output():
     return dagstermill.define_dagstermill_solid(
         'hello_world_output', nb_test_path('hello_world_output'), [], [OutputDefinition()]
@@ -142,7 +185,7 @@ def define_add_pipeline():
     )
 
 
-@solid(input_defs=[], config_field=Field(Int))
+@solid(input_defs=[], config_schema=Int)
 def load_constant(context):
     return context.solid_config
 
@@ -175,41 +218,42 @@ def define_error_pipeline():
     )
 
 
-@solid_definition
-def clean_data_solid():
-    return dagstermill.define_dagstermill_solid(
-        'clean_data', nb_test_path('clean_data'), output_defs=[OutputDefinition(DataFrame)]
-    )
+if DAGSTER_PANDAS_PRESENT and SKLEARN_PRESENT and MATPLOTLIB_PRESENT:
 
+    @solid_definition
+    def clean_data_solid():
+        return dagstermill.define_dagstermill_solid(
+            'clean_data', nb_test_path('clean_data'), output_defs=[OutputDefinition(DataFrame)]
+        )
 
-@solid_definition
-def LR_solid():
-    return dagstermill.define_dagstermill_solid(
-        'linear_regression',
-        nb_test_path('tutorial_LR'),
-        input_defs=[InputDefinition(name='df', dagster_type=DataFrame)],
-    )
+    @solid_definition
+    def LR_solid():
+        return dagstermill.define_dagstermill_solid(
+            'linear_regression',
+            nb_test_path('tutorial_LR'),
+            input_defs=[InputDefinition(name='df', dagster_type=DataFrame)],
+        )
 
+    @solid_definition
+    def RF_solid():
+        return dagstermill.define_dagstermill_solid(
+            'random_forest_regression',
+            nb_test_path('tutorial_RF'),
+            input_defs=[InputDefinition(name='df', dagster_type=DataFrame)],
+        )
 
-@solid_definition
-def RF_solid():
-    return dagstermill.define_dagstermill_solid(
-        'random_forest_regression',
-        nb_test_path('tutorial_RF'),
-        input_defs=[InputDefinition(name='df', dagster_type=DataFrame)],
-    )
-
-
-def define_tutorial_pipeline():
-    return PipelineDefinition(
-        name='tutorial_pipeline',
-        solid_defs=[clean_data_solid, LR_solid, RF_solid],
-        dependencies={
-            SolidInvocation('clean_data'): {},
-            SolidInvocation('linear_regression'): {'df': DependencyDefinition('clean_data')},
-            SolidInvocation('random_forest_regression'): {'df': DependencyDefinition('clean_data')},
-        },
-    )
+    def define_tutorial_pipeline():
+        return PipelineDefinition(
+            name='tutorial_pipeline',
+            solid_defs=[clean_data_solid, LR_solid, RF_solid],
+            dependencies={
+                SolidInvocation('clean_data'): {},
+                SolidInvocation('linear_regression'): {'df': DependencyDefinition('clean_data')},
+                SolidInvocation('random_forest_regression'): {
+                    'df': DependencyDefinition('clean_data')
+                },
+            },
+        )
 
 
 @solid('resource_solid', required_resource_keys={'list'})
@@ -266,14 +310,14 @@ class FilePickleList(object):
 
     def write(self):
         with open(self.path, 'wb') as fd:
-            pickle.dump(self.list, fd)
+            pickle.dump(self.list, fd, protocol=PICKLE_PROTOCOL)
 
     def close(self):
         self.append('Closed')
         self.closed = True
 
 
-@resource(config_field=Field(String))
+@resource(config_schema=Field(String))
 def filepicklelist_resource(init_context):
     filepicklelist = FilePickleList(init_context.resource_config)
     try:
@@ -314,20 +358,41 @@ def define_bad_kernel_pipeline():
     return PipelineDefinition(name='bad_kernel_pipeline', solid_defs=[bad_kernel_solid])
 
 
-def define_example_repository():
-    return RepositoryDefinition(
-        name='notebook_repo',
-        pipeline_dict={
-            'bad_kernel_pipeline': define_bad_kernel_pipeline,
-            'error_pipeline': define_error_pipeline,
-            'hello_world_pipeline': define_hello_world_pipeline,
-            'hello_world_config_pipeline': define_hello_world_config_pipeline,
-            'hello_world_with_output_pipeline': define_hello_world_with_output_pipeline,
-            'hello_logging_pipeline': define_hello_logging_pipeline,
-            'resource_pipeline': define_resource_pipeline,
-            'resource_with_exception_pipeline': define_resource_with_exception_pipeline,
-            'test_add_pipeline': define_add_pipeline,
-            'test_notebook_dag': define_test_notebook_dag_pipeline,
-            'tutorial_pipeline': define_tutorial_pipeline,
-        },
-    )
+reimport_solid = dagstermill.define_dagstermill_solid(
+    'reimport',
+    nb_test_path('reimport'),
+    input_defs=[InputDefinition('l', List[int])],
+    output_defs=[OutputDefinition()],
+)
+
+
+@solid
+def lister(_):
+    return [1, 2, 3]
+
+
+@pipeline
+def reimport_pipeline():
+    reimport_solid(lister())
+
+
+@repository
+def notebook_repo():
+    pipeline_dict = {
+        'bad_kernel_pipeline': define_bad_kernel_pipeline,
+        'error_pipeline': define_error_pipeline,
+        'hello_world_pipeline': define_hello_world_pipeline,
+        'hello_world_config_pipeline': define_hello_world_config_pipeline,
+        'hello_world_explicit_yield_pipeline': define_hello_world_explicit_yield_pipeline,
+        'hello_world_with_output_pipeline': define_hello_world_with_output_pipeline,
+        'hello_logging_pipeline': define_hello_logging_pipeline,
+        'resource_pipeline': define_resource_pipeline,
+        'resource_with_exception_pipeline': define_resource_with_exception_pipeline,
+        'test_add_pipeline': define_add_pipeline,
+        'test_notebook_dag': define_test_notebook_dag_pipeline,
+        'reimport_pipeline': lambda: reimport_pipeline,
+    }
+    if DAGSTER_PANDAS_PRESENT and SKLEARN_PRESENT and MATPLOTLIB_PRESENT:
+        pipeline_dict['tutorial_pipeline'] = define_tutorial_pipeline
+
+    return {'pipelines': pipeline_dict}
