@@ -15,8 +15,8 @@ from dagster import (
     check,
     seven,
 )
-from dagster.cli import load_handle
 from dagster.core.definitions.dependency import SolidHandle
+from dagster.core.definitions.reconstructable import ReconstructablePipeline
 from dagster.core.definitions.resource import ScopedResourcesBuilder
 from dagster.core.execution.api import create_execution_plan, scoped_pipeline_context
 from dagster.core.execution.resources_init import (
@@ -51,8 +51,7 @@ class DagstermillResourceEventGenerationManager(EventGenerationManager):
 
 class Manager(object):
     def __init__(self):
-        self.handle = None
-        self.pipeline_def = None
+        self.pipeline = None
         self.solid_def = None
         self.in_pipeline = False
         self.marshal_dir = None
@@ -79,10 +78,9 @@ class Manager(object):
         self,
         output_log_path=None,
         marshal_dir=None,
-        environment_dict=None,
-        handle_kwargs=None,
+        run_config=None,
+        executable_dict=None,
         pipeline_run_dict=None,
-        solid_subset=None,
         solid_handle_kwargs=None,
         instance_ref_dict=None,
     ):
@@ -99,27 +97,14 @@ class Manager(object):
         '''
         check.opt_str_param(output_log_path, 'output_log_path')
         check.opt_str_param(marshal_dir, 'marshal_dir')
-        environment_dict = check.opt_dict_param(environment_dict, 'environment_dict', key_type=str)
+        run_config = check.opt_dict_param(run_config, 'run_config', key_type=str)
         check.dict_param(pipeline_run_dict, 'pipeline_run_dict')
-        check.dict_param(handle_kwargs, 'handle_kwargs')
-        check.opt_list_param(solid_subset, 'solid_subset', of_type=str)
+        check.dict_param(executable_dict, 'executable_dict')
         check.dict_param(solid_handle_kwargs, 'solid_handle_kwargs')
         check.dict_param(instance_ref_dict, 'instance_ref_dict')
 
-        try:
-            handle = load_handle.handle_for_pipeline_cli_args(
-                handle_kwargs, use_default_repository_yaml=False
-            )
-        except (check.CheckError, load_handle.UsageError) as err:
-            six.raise_from(
-                DagstermillError(
-                    'Cannot invoke a dagstermill solid from an in-memory pipeline that was not loaded '
-                    'from an ExecutionTargetHandle. Run this pipeline using dagit, the dagster CLI, '
-                    'through dagster-graphql, or in-memory after loading it through an '
-                    'ExecutionTargetHandle.'
-                ),
-                err,
-            )
+        pipeline = ReconstructablePipeline.from_dict(executable_dict)
+        pipeline_def = pipeline.get_definition()
 
         try:
             instance_ref = unpack_value(instance_ref_dict)
@@ -132,36 +117,31 @@ class Manager(object):
                 err,
             )
 
-        pipeline_def = check.inst_param(
-            handle.build_pipeline_definition(),
-            'pipeline_def (from handle {handle_dict})'.format(handle_dict=handle.data._asdict()),
-            PipelineDefinition,
-        ).build_sub_pipeline(solid_subset)
+        pipeline_run = unpack_value(pipeline_run_dict)
 
         solid_handle = SolidHandle.from_dict(solid_handle_kwargs)
         solid_def = pipeline_def.get_solid(solid_handle).definition
 
-        pipeline_run = unpack_value(pipeline_run_dict)
-
         self.marshal_dir = marshal_dir
         self.in_pipeline = True
         self.solid_def = solid_def
-        self.pipeline_def = pipeline_def
+        self.pipeline = pipeline
 
         execution_plan = create_execution_plan(
-            self.pipeline_def,
-            environment_dict,
+            self.pipeline,
+            run_config,
             mode=pipeline_run.mode,
             step_keys_to_execute=pipeline_run.step_keys_to_execute,
         )
 
         with scoped_pipeline_context(
-            self.pipeline_def,
-            environment_dict,
+            execution_plan,
+            run_config,
             pipeline_run,
             instance,
-            execution_plan,
             scoped_resources_builder_cm=self._setup_resources,
+            # Set this flag even though we're not in test for clearer error reporting
+            raise_on_error=True,
         ) as pipeline_context:
             self.context = DagstermillRuntimeExecutionContext(
                 pipeline_context=pipeline_context,
@@ -173,7 +153,7 @@ class Manager(object):
 
         return self.context
 
-    def get_context(self, solid_config=None, mode_def=None, environment_dict=None):
+    def get_context(self, solid_config=None, mode_def=None, run_config=None):
         '''Get a dagstermill execution context for interactive exploration and development.
 
         Args:
@@ -183,14 +163,14 @@ class Manager(object):
                 use to construct the context. Specify this if you would like a context constructed
                 with specific ``resource_defs`` or ``logger_defs``. By default, an ephemeral mode
                 with a console logger will be constructed.
-            environment_dict(Optional[dict]): The environment config dict with which to construct
+            run_config(Optional[dict]): The environment config dict with which to construct
                 the context.
 
         Returns:
             :py:class:`~dagstermill.DagstermillExecutionContext`
         '''
         check.opt_inst_param(mode_def, 'mode_def', ModeDefinition)
-        environment_dict = check.opt_dict_param(environment_dict, 'environment_dict', key_type=str)
+        run_config = check.opt_dict_param(run_config, 'run_config', key_type=str)
 
         # If we are running non-interactively, and there is already a context reconstituted, return
         # that context rather than overwriting it.
@@ -201,7 +181,7 @@ class Manager(object):
 
         if not mode_def:
             mode_def = ModeDefinition(logger_defs={'dagstermill': colored_console_logger})
-            environment_dict['loggers'] = {'dagstermill': {}}
+            run_config['loggers'] = {'dagstermill': {}}
 
         solid_def = SolidDefinition(
             name='this_solid',
@@ -224,9 +204,8 @@ class Manager(object):
         pipeline_run = PipelineRun(
             pipeline_name=pipeline_def.name,
             run_id=run_id,
-            environment_dict=environment_dict,
+            run_config=run_config,
             mode=mode_def.name,
-            selector=None,
             step_keys_to_execute=None,
             status=PipelineRunStatus.NOT_STARTED,
             tags=None,
@@ -234,17 +213,14 @@ class Manager(object):
 
         self.in_pipeline = False
         self.solid_def = solid_def
-        self.pipeline_def = pipeline_def
+        self.pipeline = pipeline_def
 
-        execution_plan = create_execution_plan(
-            self.pipeline_def, environment_dict, mode=mode_def.name
-        )
+        execution_plan = create_execution_plan(self.pipeline, run_config, mode=mode_def.name)
         with scoped_pipeline_context(
-            self.pipeline_def,
-            environment_dict,
+            execution_plan,
+            run_config,
             pipeline_run,
             DagsterInstance.ephemeral(),
-            execution_plan,
             scoped_resources_builder_cm=self._setup_resources,
         ) as pipeline_context:
 
